searchData={"items":[{"type":"module","title":"Venom","doc":"Venom - Elixir NBT parser.","ref":"Venom.html"},{"type":"function","title":"Venom.decode_nbt!/1","doc":"Decode a binary representing NBT data.\n\nAlso automatically gunzips any gzip-encoded NBT.","ref":"Venom.html#decode_nbt!/1"},{"type":"function","title":"Examples - Venom.decode_nbt!/1","doc":"iex> Venom.decode_nbt!(<<10, 0, 11, 104, 101, 108, 108, 111, 32, 119, 111, 114, 108, 100, 8, 0, 4, 110, 97, 109, 101, 0, 9, 66, 97, 110, 97, 110, 114, 97, 109, 97, 0>>)\n    %{\"hello world\" => %{\"name\" => \"Bananrama\"}}","ref":"Venom.html#decode_nbt!/1-examples"},{"type":"module","title":"Venom.Parser","doc":"This module largely contains functions designed for internal use. You're probably better off using\nthe functions defined in `Venom`, unless you need to perform some specific NBT parsing yourself.","ref":"Venom.Parser.html"},{"type":"function","title":"Venom.Parser.parse_byte!/1","doc":"Parse a byte (8 bits) from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_byte!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_byte!/1","doc":"iex> Venom.Parser.parse_byte!(<<5, 0xAA, 0xBB>>)\n    {5, <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_byte!/1-examples"},{"type":"function","title":"Venom.Parser.parse_byte_array!/1","doc":"Parse an i32-length-prefixed array of bytes from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_byte_array!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_byte_array!/1","doc":"iex> Venom.Parser.parse_byte_array!(<<0, 0, 0, 4, 1, 2, 3, 4, 0xAA, 0xBB>>)\n    {[1, 2, 3, 4], <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_byte_array!/1-examples"},{"type":"function","title":"Venom.Parser.parse_double!/1","doc":"Parse a double (64 bits) from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_double!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_double!/1","doc":"iex> Venom.Parser.parse_double!(<<25, 25, 25, 25, 25, 25, 25, 25, 0xAA, 0xBB>>)\n    {9.01285756841504e-188, <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_double!/1-examples"},{"type":"function","title":"Venom.Parser.parse_float!/1","doc":"Parse a float (32 bits) from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_float!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_float!/1","doc":"iex> Venom.Parser.parse_float!(<<25, 25, 25, 25, 0xAA, 0xBB>>)\n    {7.914983038854372e-24, <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_float!/1-examples"},{"type":"function","title":"Venom.Parser.parse_int!/1","doc":"Parse an int (32 bits) from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_int!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_int!/1","doc":"iex> Venom.Parser.parse_int!(<<0, 0, 0, 5, 0xAA, 0xBB>>)\n    {5, <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_int!/1-examples"},{"type":"function","title":"Venom.Parser.parse_int_array!/1","doc":"Parse an i32-length-prefixed array of 32-bit signed ints from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_int_array!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_int_array!/1","doc":"iex> Venom.Parser.parse_int_array!(<<0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 2, 0xAA, 0xBB>>)\n    {[1, 2], <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_int_array!/1-examples"},{"type":"function","title":"Venom.Parser.parse_list!/1","doc":"","ref":"Venom.Parser.html#parse_list!/1"},{"type":"function","title":"Venom.Parser.parse_long!/1","doc":"Parse a long (64 bits) from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_long!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_long!/1","doc":"iex> Venom.Parser.parse_long!(<<0, 0, 0, 0, 0, 0, 0, 5, 0xAA, 0xBB>>)\n    {5, <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_long!/1-examples"},{"type":"function","title":"Venom.Parser.parse_long_array!/1","doc":"Parse an i32-length-prefixed array of 64-bit signed longs from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_long_array!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_long_array!/1","doc":"iex> Venom.Parser.parse_long_array!(<<0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0xAA, 0xBB>>)\n    {[1, 2], <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_long_array!/1-examples"},{"type":"function","title":"Venom.Parser.parse_root!/1","doc":"Entry-point for parsing a full NBT tag. Ensures a single-keyed compound.","ref":"Venom.Parser.html#parse_root!/1"},{"type":"function","title":"Venom.Parser.parse_short!/1","doc":"Parse a short (16 bits) from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_short!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_short!/1","doc":"iex> Venom.Parser.parse_short!(<<0, 5, 0xAA, 0xBB>>)\n    {5, <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_short!/1-examples"},{"type":"function","title":"Venom.Parser.parse_string!/1","doc":"Parse a string from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_string!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_string!/1","doc":"iex> Venom.Parser.parse_string!(<<0, 5, \"abcde\", 0xAA, 0xBB>>)\n    {\"abcde\", <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_string!/1-examples"},{"type":"function","title":"Venom.Parser.parse_tag_type!/1","doc":"Parse a tag type from a binary, returning any remaining data.","ref":"Venom.Parser.html#parse_tag_type!/1"},{"type":"function","title":"Examples - Venom.Parser.parse_tag_type!/1","doc":"iex> Venom.Parser.parse_tag_type!(<<5, 0xAA, 0xBB>>)\n    {5, <<0xAA, 0xBB>>}","ref":"Venom.Parser.html#parse_tag_type!/1-examples"},{"type":"extras","title":"Venom","doc":"# Venom\n\n**An [NBT](https://wiki.vg/NBT) decoder written in pure Elixir**","ref":"readme.html"},{"type":"extras","title":"Installation - Venom","doc":"First, add Venom to your `mix.exs` dependencies:\n\n```elixir\ndef deps do\n  [\n    {:venom, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen, update your dependencies:\n\n```\n$ mix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Venom","doc":"```elixir\niex> Venom.decode_nbt!(File.read!(\"hello_world.nbt\"))\n      %{\"hello world\" => %{\"name\" => \"Bananrama\"}}\n```","ref":"readme.html#usage"},{"type":"extras","title":"Coming Soon(?) - Venom","doc":"- Encoding support\n\nThe docs can be found at  .","ref":"readme.html#coming-soon"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}